@@ -4,6 +4,7 @@ from permuta import Perm
 
 from .abstract_strategy import EnumerationStrategy
 from .core_strategies import core_strategies
+from .finitely_many_simples import FinitelyManySimplesStrategy
 from .insertion_encodable import InsertionEncodingStrategy
 
 fast_enumeration_strategies: List[Type[EnumerationStrategy]] = [
@@ -11,7 +12,9 @@ fast_enumeration_strategies: List[Type[EnumerationStrategy]] = [
 ]
 fast_enumeration_strategies.extend(core_strategies)
 
-long_enumeration_strategies: List[Type[EnumerationStrategy]] = []
+long_enumeration_strategies: List[Type[EnumerationStrategy]] = [
+    FinitelyManySimplesStrategy
+]
 
 all_enumeration_strategies: List[Type[EnumerationStrategy]] = (
     fast_enumeration_strategies + long_enumeration_strategies
